{
*****************************
*                           *
* Author: Adrian M. Hanslik *
* Date: 31. October 1999    *
* Title: AMHWallPaperVecStd *
* Version: 1.0              *
*                           *
*****************************
}

unit AMHWallPaperVecStd;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs;

type
  TType = (stTriangle, stRectangle, stRoundRect, stEllipse);

  TMode = (smNone, smHoriz, smVert, smBoth);

  TAMHWallPaperVecStd = class(TGraphicControl)
  private
    { Private-Deklarationen }
    FBorder: Boolean;
    FBorderColor: TColor;
    FBorderWidth: Integer;
    FFilled: Boolean;
    FShadow: Boolean;
    FShadowColor: TColor;
    FShadowX: Integer;
    FShadowY: Integer;
    FShapeHeight: Integer;
    FShapeMode: TMode;
    FShapeType: TType;
    FShapeWidth: Integer;
    FXMargin: Integer;
    FYMargin: Integer;
    FXSpacing: Integer;
    FYSpacing: Integer;
    procedure SetBorder(Value: Boolean);
    procedure SetBorderColor(Value: TColor);
    procedure SetBorderWidth(Value: Integer);
    procedure SetFilled(Value: Boolean);
    procedure SetShadow(Value: Boolean);
    procedure SetShadowColor(Value: TColor);
    procedure SetShadowX(Value: Integer);
    procedure SetShadowY(Value: Integer);
    procedure SetShapeHeight(Value: Integer);
    procedure SetShapeMode(Value: TMode);
    procedure SetShapeType(Value: TType);
    procedure SetShapeWidth(Value: Integer);
    procedure SetXMargin(Value: Integer);
    procedure SetYMargin(Value: Integer);
    procedure SetXSpacing(Value: Integer);
    procedure SetYSpacing(Value: Integer);
  protected
    { Protected-Deklarationen }
    procedure DrawTriangle(X,Y:Integer);
    procedure DrawRectangle(X,Y:Integer);
    procedure DrawRoundRect(X,Y:Integer);
    procedure DrawEllipse(X,Y:Integer);
  public
    { Public-Deklarationen }
    constructor Create(AnOwner: TComponent); override;
    destructor Destroy; override;
    procedure Paint; override;
  published
    { Published-Deklarationen }
    property Border: Boolean read FBorder write SetBorder;
    property BorderColor: TColor read FBorderColor write SetBorderColor;
    property BorderWidth: Integer read FBorderWidth write SetBorderWidth;
    property Filled: Boolean read FFilled write SetFilled;
    property Shadow: Boolean read FShadow write SetShadow;
    property ShadowColor: TColor read FShadowColor write SetShadowColor;
    property ShadowX: Integer read FShadowX write SetShadowX;
    property ShadowY: Integer read FShadowY write SetShadowY;
    property ShapeHeight: Integer read FShapeHeight write SetShapeHeight;
    property ShapeMode: TMode read FShapeMode write SetShapeMode;
    property ShapeType: TType read FShapeType write SetShapeType;
    property ShapeWidth: Integer read FShapeWidth write SetShapeWidth;
    property XMargin: Integer read FXMargin write SetXMargin;
    property YMargin: Integer read FYMargin write SetYMargin;
    property XSpacing: Integer read FXSpacing write SetXSpacing;
    property YSpacing: Integer read FYSpacing write SetYSpacing;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('AMH Free', [TAMHWallPaperVecStd]);
end;

constructor TAMHWallPaperVecStd.Create(AnOwner: TComponent);
begin
  inherited Create(AnOwner);
  Align := alNone;
  Color := clBlue;
  Height := 64;
  Width := 64;
  FBorder := True;
  FBorderColor := clBlack;
  FBorderWidth := 1;
  FFilled := True;
  FShadow := True;
  FShadowColor := clDkGray;
  FShadowX := 3;
  FShadowY := 3;
  FShapeHeight := 16;
  FShapeMode := smBoth;
  FShapeType := stTriangle;
  FShapeWidth := 16;
  FXMargin := 0;
  FYMargin := 0;
  FXSpacing := 24;
  FYSpacing := 24;
end;

destructor TAMHWallPaperVecStd.Destroy;
begin
  inherited Destroy;
end;

procedure TAMHWallPaperVecStd.Paint;
var
 I, J, XN, YN, X, Y: Integer;
begin
  inherited Paint;
  XN := 1;
  YN := 1;
  if (FShapeMode in [smHoriz, smBoth]) and (XSpacing > 0) then
     XN := Width div XSpacing + 1;
  if (FShapeMode in [smVert, smBoth]) and (YSpacing > 0) then
     YN := Height div YSpacing + 1;
  for I := 1 to YN do
      for J := 1 to XN do begin
          X := (J - 1) * XSpacing + XMargin;
          Y := (I - 1) * YSpacing + YMargin;
          case FShapeType of
               stTriangle: DrawTriangle(X, Y);
               stRectangle: DrawRectangle(X, Y);
               stRoundRect: DrawRoundRect(X, Y);
               stEllipse: DrawEllipse(X, Y);
          end;
      end;
end;

procedure TAMHWallPaperVecStd.SetBorder(Value: Boolean);
begin
  if Value <> FBorder then begin
     FBorder := Value;
     Refresh;
  end;
end;

procedure TAMHWallPaperVecStd.SetBorderColor(Value: TColor);
begin
  if Value <> FBorderColor then begin
     FBorderColor := Value;
     Refresh;
  end;
end;

procedure TAMHWallPaperVecStd.SetBorderWidth(Value: Integer);
begin
  if Value <> FBorderWidth then begin
     FBorderWidth := Value;
     Refresh;
  end;
end;

procedure TAMHWallPaperVecStd.SetFilled(Value: Boolean);
begin
  if Value <> FFilled then begin
     FFilled := Value;
     Refresh;
  end;
end;

procedure TAMHWallPaperVecStd.SetShadow(Value: Boolean);
begin
  if Value <> FShadow then begin
     FShadow := Value;
     Refresh;
  end;
end;

procedure TAMHWallPaperVecStd.SetShadowColor(Value: TColor);
begin
  if Value <> FShadowColor then begin
     FShadowColor := Value;
     Refresh;
  end;
end;

procedure TAMHWallPaperVecStd.SetShadowX(Value: Integer);
begin
  if Value <> FShadowX then begin
     FShadowX := Value;
     Refresh;
  end;
end;

procedure TAMHWallPaperVecStd.SetShadowY(Value: Integer);
begin
  if Value <> FShadowY then begin
     FShadowY := Value;
     Refresh;
  end;
end;

procedure TAMHWallPaperVecStd.SetShapeHeight(Value: Integer);
begin
  if Value <> FShapeHeight then begin
     FShapeHeight := Value;
     Refresh;
  end;
end;

procedure TAMHWallPaperVecStd.SetShapeMode(Value: TMode);
begin
  if Value <> FShapeMode then begin
     FShapeMode := Value;
     Refresh;
  end;
end;

procedure TAMHWallPaperVecStd.SetShapeType(Value: TType);
begin
  if Value <> FShapeType then begin
     FShapeType := Value;
     Refresh;
  end;
end;

procedure TAMHWallPaperVecStd.SetShapeWidth(Value: Integer);
begin
  if Value <> FShapeWidth then begin
     FShapeWidth := Value;
     Refresh;
  end;
end;

procedure TAMHWallPaperVecStd.SetXMargin(Value: Integer);
begin
  if Value <> FXMargin then begin
     FXMargin := Value;
     Refresh;
  end;
end;

procedure TAMHWallPaperVecStd.SetYMargin(Value: Integer);
begin
  if Value <> FYMargin then begin
     FYMargin := Value;
     Refresh;
  end;
end;

procedure TAMHWallPaperVecStd.SetXSpacing(Value: Integer);
begin
  if Value <> FXSpacing then begin
     FXSpacing := Value;
     Refresh;
  end;
end;

procedure TAMHWallPaperVecStd.SetYSpacing(Value: Integer);
begin
  if Value <> FYSpacing then begin
     FYSpacing := Value;
     Refresh;
  end;
end;

procedure TAMHWallPaperVecStd.DrawTriangle(X,Y:Integer);
var
  I, SW, SH: Integer;
  Pt, ShPt: array [1..4] of TPoint;
begin
  SW := (ShapeWidth div 2) * 2;
  SH := (ShapeHeight div 2) * 2;
  Pt[1].X := X;
  Pt[1].Y := Y;
  Pt[2].X := X + SW;
  Pt[2].Y := Y + SH div 2;
  Pt[3].X := X;
  Pt[3].Y := Y + SH;
  Pt[4] := Pt[1];
  if Shadow then begin
     for I := 1 to 4 do begin
         ShPt[i] := Pt[i];
         Inc(ShPt[i].X, ShadowX);
         Inc(ShPt[i].Y, ShadowY);
     end;
     Canvas.Brush.Color := ShadowColor;
     Canvas.Pen.Color := ShadowColor;
     Canvas.Pen.Width := 1;
     if Filled then
        Canvas.Polygon(ShPt)
     else
         Canvas.PolyLine(ShPt);
  end;
  if Border then
     Canvas.Pen.Color := BorderColor
  else
      Canvas.Pen.Color := Color;
  Canvas.Brush.Color := Color;
  Canvas.Pen.Width := BorderWidth;
  if Filled then
     Canvas.Polygon(Pt)
  else
      Canvas.PolyLine(Pt);
end;

procedure TAMHWallPaperVecStd.DrawRectangle(X,Y:Integer);
var
  SX, SY, I: Integer;
  Pt, ShPt: array [1..5] of TPoint;
begin
  Pt[1].X := X;
  Pt[1].Y := Y;
  Pt[2].X := X + ShapeWidth;
  Pt[2].Y := Y;
  Pt[3].X := X + ShapeWidth;
  Pt[3].Y := Y + ShapeHeight;
  Pt[4].X := X;
  Pt[4].Y := Y + ShapeHeight;
  Pt[5] := Pt[1];
  if Shadow then begin
     for I := 1 to 5 do begin
         ShPt[i] := Pt[i];
         Inc(ShPt[I].X, ShadowX);
         Inc(ShPt[I].Y, ShadowY);
     end;
     SX := X + ShadowX;
     SY := Y + ShadowY;
     Canvas.Brush.Color := ShadowColor;
     Canvas.Pen.Color := ShadowColor;
     Canvas.Pen.Width := 1;
     if Filled then
        Canvas.Rectangle(SX, SY, SX + ShapeWidth, SY + ShapeHeight)
     else
         Canvas.PolyLine(ShPt);
  end;
  if Border then
     Canvas.Pen.Color := BorderColor
  else
      Canvas.Pen.Color := Color;
  Canvas.Pen.Width := BorderWidth;
  Canvas.Brush.Color := Color;
  if Filled then
     Canvas.Rectangle(X, Y, X + ShapeWidth, Y + ShapeHeight)
  else
      Canvas.PolyLine(Pt);
end;

procedure TAMHWallPaperVecStd.DrawRoundRect(X,Y:Integer);
var
  SX, SY: Integer;
begin
  if Shadow then begin
     SX := X + ShadowX;
     SY := Y + ShadowY;
     Canvas.Brush.Color := ShadowColor;
     Canvas.Pen.Color := ShadowColor;
     Canvas.Pen.Width := 1;
     Canvas.RoundRect(SX, SY, SX + ShapeWidth, SY + ShapeHeight, ShapeWidth div 2, ShapeHeight div 2);
  end;
  if Border then
     Canvas.Pen.Color := BorderColor
  else
      Canvas.Pen.Color := Color;
  Canvas.Brush.Color := Color;
  Canvas.Pen.Width := BorderWidth;
  Canvas.RoundRect(X, Y, X + ShapeWidth, Y + ShapeHeight, ShapeWidth div 2, ShapeHeight div 2);
end;

procedure TAMHWallPaperVecStd.DrawEllipse(X,Y:Integer);
var
  SX, SY: Integer;
begin
  if Shadow then begin
     SX := X + ShadowX;
     SY := Y + ShadowY;
     Canvas.Brush.Color := ShadowColor;
     Canvas.Pen.Color := ShadowColor;
     Canvas.Pen.Width := 1;
     if Filled then
        Canvas.Ellipse(SX, SY, SX + ShapeWidth, SY + ShapeHeight)
     else
         Canvas.Arc(SX, SY, SX + ShapeWidth, SY + ShapeHeight, SX, SY, SX, SY);
  end;
  if Border then
     Canvas.Pen.Color := BorderColor
  else
      Canvas.Pen.Color := Color;
  Canvas.Brush.Color := Color;
  Canvas.Pen.Width := BorderWidth;
  if Filled then
     Canvas.Ellipse(X, Y, X + ShapeWidth, Y + ShapeHeight)
  else
      Canvas.Arc(X, Y, X + ShapeWidth, Y + ShapeHeight, X, Y, X, Y);
end;

end.
